@@ -208,6 +208,12 @@ fviz <- function(X, element, axes = c(1, 2), geom = "auto",
     df[[.col.name]] <- fill
     fill <- .col.name
   }
+  # Augment the data, if pointsize is a continuous variable
+  if(length(pointsize) > 1){
+    if(nrow(df) != length(pointsize)) pointsize <- 1.5
+    df[["pointsize"]] <- pointsize
+    pointsize <- "pointsize"
+  }
   # Selection
   df.all <- df
   if(!is.null(select)) df <- .select(df, select)
